"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from dataclasses_json import Undefined, dataclass_json
from leonardoaisdk import utils
from typing import Optional


@dataclasses.dataclass
class DeleteInitImageByIDRequest:
    id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'id', 'style': 'simple', 'explode': False }})
    r"""_\\"id\\" is required_"""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class InitImages:
    r"""columns and relationships of \\"init_images\\" """
    UNSET='__SPEAKEASY_UNSET__'
    id: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id'), 'exclude': lambda f: f is InitImages.UNSET }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class DeleteInitImageByIDResponseBody:
    r"""Responses for DELETE /init-image/{id}"""
    UNSET='__SPEAKEASY_UNSET__'
    delete_init_images_by_pk: Optional[InitImages] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('delete_init_images_by_pk'), 'exclude': lambda f: f is DeleteInitImageByIDResponseBody.UNSET }})
    r"""columns and relationships of \\"init_images\\" """
    



@dataclasses.dataclass
class DeleteInitImageByIDResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    raw_response: requests_http.Response = dataclasses.field()
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: Optional[DeleteInitImageByIDResponseBody] = dataclasses.field(default=None)
    r"""Responses for DELETE /init-image/{id}"""
    

